@@ -203,6 +203,9 @@ FAILEDOPERATION_TKECLUSTERDELETEFAILED = 'FailedOperation.TkeClusterDeleteFailed
 # TKE 集群查询失败。
 FAILEDOPERATION_TKECLUSTERQUERYFAILED = 'FailedOperation.TkeClusterQueryFailed'
 
+# TOKEN查询失败。
+FAILEDOPERATION_TOKENQUERYFAILED = 'FailedOperation.TokenQueryFailed'
+
 # TSF应用性能管理任务数据库查询失败。
 FAILEDOPERATION_TSFAPMAGENTTASKQUERYERROR = 'FailedOperation.TsfApmAgentTaskQueryError'
 
@@ -563,6 +566,9 @@ INVALIDPARAMETERVALUE_APPLICATIONNAMEREGXINVALID = 'InvalidParameterValue.Applic
 # 无法获取应用。
 INVALIDPARAMETERVALUE_APPLICATIONNOTEXISTS = 'InvalidParameterValue.ApplicationNotExists'
 
+# 无效的应用排序类型。
+INVALIDPARAMETERVALUE_APPLICATIONORDERTYPEINVALID = 'InvalidParameterValue.ApplicationOrderTypeInvalid'
+
 # 无效的应用分页参数。
 INVALIDPARAMETERVALUE_APPLICATIONPAGELIMITINVALID = 'InvalidParameterValue.ApplicationPageLimitInvalid'
 
@@ -644,6 +650,9 @@ INVALIDPARAMETERVALUE_CONTAINERGROUPAPPLICATIONIDNULL = 'InvalidParameterValue.C
 # 集群 CPU 资源不足。
 INVALIDPARAMETERVALUE_CONTAINERGROUPCPULIMITOVER = 'InvalidParameterValue.ContainergroupCpulimitOver'
 
+# 容器 Env 的 Value 和 ValueFrom 至少要有一个。
+INVALIDPARAMETERVALUE_CONTAINERGROUPENVVALUENOTSET = 'InvalidParameterValue.ContainergroupEnvValueNotSet'
+
 # 部署组ID不能为空。
 INVALIDPARAMETERVALUE_CONTAINERGROUPGROUPIDNULL = 'InvalidParameterValue.ContainergroupGroupidNull'
 
@@ -734,6 +743,9 @@ INVALIDPARAMETERVALUE_DEPLOYGROUPNOTEXISTS = 'InvalidParameterValue.DeployGroupN
 # 文件配置项已经发布。
 INVALIDPARAMETERVALUE_FILECONFIGALREADYRELEASED = 'InvalidParameterValue.FileConfigAlreadyReleased'
 
+# 文件配置项编码方式不支持。
+INVALIDPARAMETERVALUE_FILECONFIGCODEUNSUPPORTED = 'InvalidParameterValue.FileConfigCodeUnsupported'
+
 # 文件配置项已存在。
 INVALIDPARAMETERVALUE_FILECONFIGEXISTS = 'InvalidParameterValue.FileConfigExists'
 
@@ -749,6 +761,9 @@ INVALIDPARAMETERVALUE_FILECONFIGFILENAMEINVALID = 'InvalidParameterValue.FileCon
 # 文件配置项文件路径不合规。
 INVALIDPARAMETERVALUE_FILECONFIGFILEPATHINVALID = 'InvalidParameterValue.FileConfigFilePathInvalid'
 
+# 文件配置项固定字段不可变更。
+INVALIDPARAMETERVALUE_FILECONFIGFIXEDFIELDUNCHANGEABLE = 'InvalidParameterValue.FileConfigFixedFieldUnchangeable'
+
 # 文件配置项名称不合规。
 INVALIDPARAMETERVALUE_FILECONFIGNAMEINVALID = 'InvalidParameterValue.FileConfigNameInvalid'
 
@@ -929,6 +944,9 @@ INVALIDPARAMETERVALUE_SERVICENOTEXISTSORPERMISSIONDENIED = 'InvalidParameterValu
 # 无效请求参数。
 INVALIDPARAMETERVALUE_TASKPARAMETERINVALID = 'InvalidParameterValue.TaskParameterInvalid'
 
+# TSF应用性能管理业务日志搜索解析时间格式错误。
+INVALIDPARAMETERVALUE_TSFAPMBUSILOGSEARCHPARSERSPDATEFORMATERROR = 'InvalidParameterValue.TsfApmBusiLogSearchParseRspDateFormatError'
+
 # 仅有停止状态下的部署组才可以不启动。
 INVALIDPARAMETERVALUE_WRONGDONTSTARTVALUE = 'InvalidParameterValue.WrongDontStartValue'
 
